package com.ygtx.gxt.service;

import java.util.List;
import com.ygtx.gxt.domain.GxtEquipment;

/**
 * 设备管理Service接口
 * 
 * @author ouyj
 * @date 2025-10-28
 */
public interface IGxtEquipmentService 
{
    /**
     * 查询设备管理
     * 
     * @param equipmentId 设备管理主键
     * @return 设备管理
     */
    public GxtEquipment selectGxtEquipmentByEquipmentId(Long equipmentId);

    /**
     * 查询设备管理列表
     * 
     * @param gxtEquipment 设备管理
     * @return 设备管理集合
     */
    public List<GxtEquipment> selectGxtEquipmentList(GxtEquipment gxtEquipment);

    /**
     * 查询所有品牌列表（去重）
     * 
     * @return 品牌列表
     */
    public List<String> selectBrandList();

    /**
     * 根据品牌查询机型列表（去重）
     * 
     * @param brand 品牌
     * @return 机型列表
     */
    public List<String> selectModelListByBrand(String brand);

    /**
     * 根据设备编码查询设备管理
     * 
     * @param equipmentCode 设备编码
     * @return 设备管理
     */
    public GxtEquipment selectGxtEquipmentByEquipmentCode(String equipmentCode);

    /**
     * 根据设备编码、维保中心和场站查询设备管理
     * 
     * @param equipment 设备信息
     * @return 设备管理
     */
    public GxtEquipment selectGxtEquipmentByCodeAndLocation(GxtEquipment equipment);

    /**
     * 新增设备管理
     * 
     * @param gxtEquipment 设备管理
     * @return 结果
     */
    public int insertGxtEquipment(GxtEquipment gxtEquipment);

    /**
     * 修改设备管理
     * 
     * @param gxtEquipment 设备管理
     * @return 结果
     */
    public int updateGxtEquipment(GxtEquipment gxtEquipment);

    /**
     * 批量删除设备管理
     * 
     * @param equipmentIds 需要删除的设备管理主键集合
     * @return 结果
     */
    public int deleteGxtEquipmentByEquipmentIds(Long[] equipmentIds);

    /**
     * 删除设备管理信息
     * 
     * @param equipmentId 设备管理主键
     * @return 结果
     */
    public int deleteGxtEquipmentByEquipmentId(Long equipmentId);

    /**
     * 导入设备管理数据
     * 
     * @param equipmentList 设备管理数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importGxtEquipment(List<GxtEquipment> equipmentList, Boolean isUpdateSupport, String operName);
}